Learn R Programming

NMMIPW (version 0.1.0)

regress_fit: This function returns the residuls after fiting a func regression, where func is the user-specified function

Description

This function returns the residuls after fiting a func regression, where func is the user-specified function

Usage

regress_fit(
  coefficients,
  regress_func,
  formula,
  data,
  weights,
  R,
  sigma_star,
  pattern,
  ...
)

Arguments

Value

returns the residuals of the regression by the user-specified function