powered by
This function returns the residuls after fiting a func regression, where func is the user-specified function
regress_fit( coefficients, regress_func, formula, data, weights, R, sigma_star, pattern, ... )
returns the residuals of the regression by the user-specified function